import json
from pathlib import Path

from shared import get_epds, get_full_epd


def get_folder(source, name: str) -> Path:
    """Get or create a folder with the given name"""

    folder = Path(source).parent / name
    if not folder.exists():
        folder.mkdir()

    return folder


def download_epds(data_folder: Path, search_key: str):
    """Download 50 EPDs and save them locally"""

    data = get_epds({"name": search_key}, limit=50)

    for epd in data.get("data"):
        epd_id = epd.get("uuid")
        print(f"Downloading EPD: {epd_id[:8]} to {'/'.join(data_folder.parts[-3:])}")

        _epd = get_full_epd(epd_id)
        (data_folder / f"{epd_id}.json").write_text(json.dumps(_epd, indent=2))


if __name__ == "__main__":
    _folder = get_folder(__file__, "data")

    download_epds(_folder, "beton")
